#
#  Copyright (c) 2010, Texas Instruments Incorporated
#  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions
#  are met:
#
#  *  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#  *  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
#  *  Neither the name of Texas Instruments Incorporated nor the names of
#     its contributors may be used to endorse or promote products derived
#     from this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
#  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
#  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

#
#  ======== xdcpathcheck.mak ========
#  This file checks various paths set in xdcpaths.mak for their correctness
#  Also complains if required toolchains are not set by the user.  
# -----------------------------------------------------------------------------

# Most users have no need to modify anything in this file 

# -----------------------------------------------------------------------------

# If we're a subcomponent, allow larger product settings to override our
# defaults.  The variable $(RULES_MAKE) can be overridden on the 'make'
# command-line if the location below is not correct (for example, if you
# want to use a Rules.make from some other location.
RULES_MAKE := $(FC_INSTALL_DIR)/../Rules.make
ifneq ($(wildcard $(RULES_MAKE)),)
include $(RULES_MAKE)
endif

# Note, some good defensive programming here could be to ensure $(DEVICES) and
# $(PROGRAMS) - and others! - don't contain any space characters

#
# Set XDCARGS to some of the variables above.  xdcrules.mak will pass this
# variable to the XDC build engine... which will load config.bld... which will
# extract these variables and use them to determine what to build and which
# toolchains to use.
#
# Note that not all of these variables need to be set to something valid.
# Unfortunately, since these vars are unconditionally assigned, your build line
# will be longer and more noisy than necessary (e.g., it will include CC_V5T
# assignment even if you're just building for WinCE.  While benign, it is
# annoying.  In future releases, we'll clean up this XDCARGS assignment and
# only include the vars that are required.
#
# Some background is here:
#     http://rtsc.eclipse.org/docs-tip/Command_-_xdc#Environment_Variables
#
XDCARGS= DEVICES=\"$(DEVICES)\" \
    PROGRAMS=\"$(PROGRAMS)\" \
    GPPOS=\"$(GPPOS)\" \
    CGTOOLS_V5T=\"$(CGTOOLS_V5T)\" \
    CC_V5T=\"$(CC_V5T)\" \
    CGTOOLS_C64P=\"$(CGTOOLS_C64P)\" \
    CGTOOLS_C64Pelf=\"$(CGTOOLS_C64Pelf)\" \
    CGTOOLS_C66=\"$(CGTOOLS_C66)\" \
    CGTOOLS_C66elf=\"$(CGTOOLS_C66elf)\" \
    CGTOOLS_M3elf=\"$(CGTOOLS_M3elf)\" \
    CGTOOLS_C674=\"$(CGTOOLS_C674)\" \
    CGTOOLS_C674elf=\"$(CGTOOLS_C674elf)\" \
    CGTOOLS_C64Telf=\"$(CGTOOLS_C64Telf )\" \
    CGTOOLS_LINUX86=\"$(CGTOOLS_LINUX86)\" \
    CGTOOLS_UCARM9=\"$(CGTOOLS_UCARM9)\" \
    ELF=$(ELF)

# -----------------------------------------------------------------------------

# Utility variables - useful for over-riding these repos from the cmd line
FC_REPO ?= $(FC_INSTALL_DIR)/packages
FCTOOLS_REPO ?= $(FC_INSTALL_DIR)/fctools/packages

# Determine which components are necessary based on settings above
# Note, this ultimately just sets up the XDCPATH, and provides ease-of-use
# errors when we can catch them here, rather than progress further downstream
# and get [stranger] errors later

# All configurations require XDC, XDAIS and FC, and OSAL (?!)
REQUIRE_FC    := 1
REQUIRE_XDC   := 1
REQUIRE_XDAIS := 1
REQUIRE_OSAL  := 1

# TODO Need to improve these CE-type checks for the above, right now, say yes
# to everything            
REQUIRE_LINUXUTILS := 1
REQUIRE_EDMA3LLD := 1
REQUIRE_BIOS := 1

ifneq (,$(findstring DM8168CATALOG,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_M3elf := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_M3elf := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
endif
ifneq (,$(findstring DM8148,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
endif

ifneq (,$(findstring TI816X,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
endif


ifneq (,$(findstring OMAP4430,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_M3elf := 1
        REQUIRE_CGTOOLS_C64Telf  := 1
    endif
endif

ifneq (,$(findstring 6472,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C64P := 1
    ifeq ($(ELF), 1)
        REQUIRE_CGTOOLS_C64Pelf := 1
    endif
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring 6474,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C64P := 1
    ifeq ($(ELF), 1)
        REQUIRE_CGTOOLS_C64Pelf := 1
    endif
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring 6670,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C66elf := 1
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring 6678,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C66elf := 1
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring 6616,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C66 := 1
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring 6608,$(DEVICES)))
    REQUIRE_BIOS := 1
    REQUIRE_CGTOOLS_C66 := 1
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_IPC := 1
    endif
endif

ifneq (,$(findstring DM6446,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_LINUXUTILS := 1
            REQUIRE_CGTOOLS_V5T := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_LINUXUTILS := 1
            REQUIRE_CGTOOLS_UCARM9 := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_LINUXUTILS := 1
            REQUIRE_CGTOOLS_V5T := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_LINUXUTILS := 1
            REQUIRE_CGTOOLS_UCARM9 := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring DM6467,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring DM355,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
endif

ifneq (,$(findstring DM357,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
endif

ifneq (,$(findstring DM365,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
endif

ifneq (,$(findstring DM6437,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring DM648,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring OMAP2530,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring OMAP3530,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C64P := 1
    endif
endif

ifneq (,$(findstring OMAPL137,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
endif

ifneq (,$(findstring OMAPL138,$(DEVICES)))
    ifneq (, $(findstring APP_CLIENT, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_V5T := 1
            REQUIRE_LINUXUTILS := 1
        endif
        ifneq (, $(findstring LINUX_UCLIBC, $(GPPOS) ))
            REQUIRE_CGTOOLS_UCARM9 := 1
            REQUIRE_LINUXUTILS := 1
        endif
    endif
    ifneq (, $(findstring DSP_SERVER, $(PROGRAMS) ))
        REQUIRE_LINK := 1
        REQUIRE_IPC := 1
        REQUIRE_BIOS := 1
        REQUIRE_CGTOOLS_C674 := 1
    endif
endif

ifneq (,$(findstring X86,$(DEVICES)))
    ifneq (, $(findstring APP_LOCAL, $(PROGRAMS) ))
        ifneq (, $(findstring LINUX_GCC, $(GPPOS) ))
            REQUIRE_CGTOOLS_LINUX86 := 1
        endif
    endif
endif

# EDMA3LLD is potentially required for all BIOS-based environments
ifeq ($(REQUIRE_BIOS), 1)
    REQUIRE_EDMA3LLD := 1
endif




# Build the XDC path from the necessary components, verifying along the way
# that the required compoments are present
XDC_PATH :=

ERRMSG = which is invalid (could not find file "$(TEST_FILE)"). Set this in <framework components examples>/xdcpaths.mak! See the build documentation to correct this error.

# FC_INSTALL_DIR is the location of your FC installation 
ifeq ($(REQUIRE_FC), 1)
    TEST_FILE := $(FC_REPO)/ti/sdo/fc/global/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error FC_INSTALL_DIR is set to "$(FC_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(FC_REPO)
endif

# Add fctools to XDCPATH if 1) $(USE_FCTOOLS_IF_EXISTS) is set, and
# 2) the FC distribution has "fctools/"
USING_FCTOOLS := 0
ifeq ($(USE_FCTOOLS_IF_EXISTS), 1)
    ifneq ($(wildcard $(FCTOOLS_REPO)),)
        USING_FCTOOLS := 1
        XDC_PATH := $(FCTOOLS_REPO);$(XDC_PATH)
    endif
endif
ifeq ($(USING_FCTOOLS),0)
    # XDAIS_INSTALL_DIR is the location of your XDAIS distribution
    ifeq ($(REQUIRE_XDAIS), 1)
        TEST_FILE := $(XDAIS_INSTALL_DIR)/packages/ti/xdais/package.xdc
	ifeq ($(FILECHK), 1)
        ifeq ($(wildcard $(TEST_FILE)),)
            $(error XDAIS_INSTALL_DIR is set to "$(XDAIS_INSTALL_DIR)", $(ERRMSG))
        endif
	endif
        XDC_PATH := $(XDC_PATH);$(XDAIS_INSTALL_DIR)/packages
    endif

    # CMEM_INSTALL_DIR is the location of your Linux Utils distribution
    ifeq ($(REQUIRE_LINUXUTILS), 1)
        TEST_FILE := $(CMEM_INSTALL_DIR)/packages/ti/sdo/linuxutils/cmem/package.xdc
	ifeq ($(FILECHK), 1)
        ifeq ($(wildcard $(TEST_FILE)),)
            $(error CMEM_INSTALL_DIR is set to "$(CMEM_INSTALL_DIR)", $(ERRMSG))
        endif
	endif
        XDC_PATH := $(XDC_PATH);$(CMEM_INSTALL_DIR)/packages
    endif

    # EDMA3_LLD_INSTALL_DIR is the location of your EDMA3 LLD distribution
    ifeq ($(REQUIRE_EDMA3LLD), 1)
        TEST_FILE := $(EDMA3_LLD_INSTALL_DIR)/packages/ti/sdo/edma3/rm/package.xdc
	ifeq ($(FILECHK), 1)
        ifeq ($(wildcard $(TEST_FILE)),)
            $(error EDMA3_LLD_INSTALL_DIR is set to "$(EDMA3_LLD_INSTALL_DIR)", $(ERRMSG))
        endif
	endif
       XDC_PATH := $(XDC_PATH);$(EDMA3_LLD_INSTALL_DIR)/packages
    endif

endif

# BIOS_INSTALL_DIR is the location of your BIOS distribution
ifeq ($(REQUIRE_BIOS), 1)
    TEST_FILE := $(BIOS_INSTALL_DIR)/packages/ti/bios/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error BIOS_INSTALL_DIR is set to "$(BIOS_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(XDC_PATH);$(BIOS_INSTALL_DIR)/packages
endif

# EDMA3_LLD_INSTALL_DIR is the location of your EDMA3 LLD distribution
ifeq ($(REQUIRE_EDMA3LLD), 1)
    TEST_FILE := $(EDMA3_LLD_INSTALL_DIR)/packages/ti/sdo/edma3/rm/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error EDMA3_LLD_INSTALL_DIR is set to "$(EDMA3_LLD_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(XDC_PATH);$(EDMA3_LLD_INSTALL_DIR)/packages
endif

# SYSLINK_INSTALL_DIR is the location of your SYSLINK distribution
ifeq ($(REQUIRE_LINK), 1)
    TEST_FILE := $(SYSLINK_INSTALL_DIR)/packages/ti/syslink/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error SYSLINK_INSTALL_DIR is set to "$(SYSLINK_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(XDC_PATH);$(SYSLINK_INSTALL_DIR)/packages
endif

# IPC_INSTALL_DIR is the location of your IPC distribution
ifeq ($(REQUIRE_IPC), 1)
    TEST_FILE := $(IPC_INSTALL_DIR)/packages/ti/sdo/ipc/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error IPC_INSTALL_DIR is set to "$(IPC_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(XDC_PATH);$(IPC_INSTALL_DIR)/packages
endif

# OSAL_INSTALL_DIR is the location of your XDCTOOLS installation.
ifeq ($(REQUIRE_OSAL), 1)
    TEST_FILE := $(OSAL_INSTALL_DIR)/packages/ti/sdo/xdcruntime/linux/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error OSAL_INSTALL_DIR is set to "$(OSAL_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
    XDC_PATH := $(XDC_PATH);$(OSAL_INSTALL_DIR)/packages
endif

# XDC_INSTALL_DIR is the location of your XDCTOOLS installation.
ifeq ($(REQUIRE_XDC), 1)
    TEST_FILE := $(XDC_INSTALL_DIR)/packages/xdc/package.xdc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error XDC_INSTALL_DIR is set to "$(XDC_INSTALL_DIR)", $(ERRMSG))
    endif
    endif
endif


# CGTOOLS_M3elf is the location of your CGtools for M3elf.
ifeq ($(REQUIRE_CGTOOLS_M3elf), 1)
    TEST_FILE := $(CGTOOLS_M3elf)/bin/cl470*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_M3elf is set to "$(CGTOOLS_M3elf)", $(ERRMSG))
    endif
    endif
endif

# CGTOOLS_C64P is the location of your CGtools for C64P.
ifeq ($(REQUIRE_CGTOOLS_C64P), 1)
    TEST_FILE := $(CGTOOLS_C64P)/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C64P is set to "$(CGTOOLS_C64P)", $(ERRMSG))
    endif
    endif
endif


# CGTOOLS_C66 is the location of your CGtools for C66.
ifeq ($(REQUIRE_CGTOOLS_C66), 1)
    TEST_FILE := $(CGTOOLS_C66)/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C66 is set to "$(CGTOOLS_C66)", $(ERRMSG))
    endif
    endif
endif


# CGTOOLS_C64Pelf is the location of your CGtools for C64Pelf
ifeq ($(REQUIRE_CGTOOLS_C64Pelf), 1)
    TEST_FILE := $(CGTOOLS_C64Pelf)/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C64Pelf is set to "$(CGTOOLS_C64Pelf)", $(ERRMSG))
    endif
    endif
endif


# CGTOOLS_C66elf is the location of your CGtools for C66elf
ifeq ($(REQUIRE_CGTOOLS_C66elf), 1)
    TEST_FILE := $(CGTOOLS_C66elf)/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C66elf is set to "$(CGTOOLS_C66elf)", $(ERRMSG))
    endif
    endif
endif

# CGTOOLS_C674 is the location of your CGtools for C674.
ifeq ($(REQUIRE_CGTOOLS_C674), 1)
    TEST_FILE := $(CGTOOLS_C674)/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C674 is set to "$(CGTOOLS_C674)", $(ERRMSG))
    endif
    endif
endif

# CGTOOLS_C64Telf  is the location of your CGtools for C64Telf .
ifeq ($(REQUIRE_CGTOOLS_C64Telf ), 1)
    TEST_FILE := $(CGTOOLS_C64Telf )/bin/cl6x*
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_C64Telf  is set to "$(CGTOOLS_C64Telf )", $(ERRMSG))
    endif
    endif
endif


# CGTOOLS_V5T is the location of your CGtools for GCC Linux.
ifeq ($(REQUIRE_CGTOOLS_V5T), 1)
    TEST_FILE := $(CGTOOLS_V5T)/$(CC_V5T)
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_V5T/CC_V5T is set to "$(CGTOOLS_V5T)/$(CC_V5T)", $(ERRMSG))
    endif
    endif
endif

# CGTOOLS_UCARM9 is the location of your CGtools for uclibc Linux.
ifeq ($(REQUIRE_CGTOOLS_UCARM9), 1)
    TEST_FILE := $(CGTOOLS_UCARM9)/$(CC_UCARM9)
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_UCARM9/CC_UCARM9 is set to "$(CGTOOLS_UCARM9)/$(CC_UCARM9)", $(ERRMSG))
    endif
    endif
endif

# CGTOOLS_LINUX86 is the location of your CGtools for X86 Linux.
ifeq ($(REQUIRE_CGTOOLS_LINUX86), 1)
    TEST_FILE := $(CGTOOLS_LINUX86)/bin/gcc
    ifeq ($(FILECHK), 1)
    ifeq ($(wildcard $(TEST_FILE)),)
        $(error CGTOOLS_LINUX86 is set to "$(CGTOOLS_LINUX86)", $(ERRMSG))
    endif
    endif
endif

# XDC_PATH is complete. Any other components you could add as
ifneq ($(MY_XDC_PATH),)
    XDC_PATH := $(MY_XDC_PATH);$(XDC_PATH)
endif
