/* 
 * Copyright (c) 2011, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */


/*
 *  ======== Server.c ========
 *
 */

/* this define must precede inclusion of any xdc header file */
#define Registry_CURDESC App__Desc
#define MODULE_NAME "App"

#include <string.h>

/* xdctools header files */
#include <xdc/std.h>
#include <xdc/runtime/Assert.h>
#include <xdc/runtime/Diags.h>
#include <xdc/runtime/Log.h>
#include <xdc/runtime/Registry.h>

/* package header files */
#include <ti/sdo/rcm/RcmServer.h>
#include <ti/sdo/rcm/examples/appcfg/App.h>

/* local header files */
#include "Global.h"

/* private functions */
static Int32 App_hello_fxn(UInt32 dataSize, UInt32 *data);

/* private data */
static Int curInit = 0;
Registry_Desc Registry_CURDESC; /* module diags mask */

/* RcmServer static function table */
static RcmServer_FxnDesc serverFxnAry[] = {
    { "Hello",  App_hello_fxn }
};

#define serverFxnAryLen (sizeof serverFxnAry / sizeof serverFxnAry[0])

static const RcmServer_FxnDescAry Server_fxnTab = {
    serverFxnAryLen,
    serverFxnAry
};

static RcmServer_Handle rcmServerH = NULL;


/*
 *  ======== App_init ========
 */
Void App_init(Void)
{
    Registry_Result result;


    if (curInit++ != 0) {
        return;  /* already initialized */
    }

    /* register with xdc.runtime to get a diags mask */
    result = Registry_addModule(&Registry_CURDESC, MODULE_NAME);
    Assert_isTrue(result == Registry_SUCCESS, (Assert_Id)NULL);

    RcmServer_init();
}


/*
 *  ======== App_exit ========
 */
Void App_exit(Void)
{
//  Registry_Result result;


    if (curInit-- != 1) {
        return;  /* object still being used */
    }

    RcmServer_exit();

    /* unregister from xdc.runtime */
//  result = Registry_removeModule(MODULE_NAME);
//  Assert_isTrue(result == Registry_SUCCESS, (Assert_Id)NULL);
}


/*
 *  ======== App_startup ========
 */
#define FXNN "App_startup"
Int App_startup(App_Object *app)
{
    RcmServer_Params rcmServerP;
    Int status = 0;


    Log_print1(Diags_ENTRY | Diags_INFO, "--> "FXNN": (app=0x%x)", (IArg)app);

    /* initialize RcmServer create params */
    RcmServer_Params_init(&rcmServerP);
    rcmServerP.fxns.length = Server_fxnTab.length;
    rcmServerP.fxns.elem = Server_fxnTab.elem;

    /* create the RcmServer instance */
    status = RcmServer_create(Global_RcmServerName, &rcmServerP, &rcmServerH);

    if (status < 0) {
        Log_error1(FXNN": RcmServer_create() returned error %d", (IArg)status);
        goto leave;
    }

    /* start the server */
    RcmServer_start(rcmServerH);


leave:
    Log_print1(Diags_EXIT, "<-- "FXNN": %d", (IArg)status);
    return(status);
}
#undef FXNN


/*
 *  ======== App_hello_fxn ========
 *
 *  data[0]    out Int          status
 *  data[1-31] out Char[124]    message
 */
Int32 App_hello_fxn(UInt32 dataSize, UInt32 *data)
{
    Char *cp;

    /* write message into payload */
    cp = (Char *)(&data[1]);
    strcpy(cp, "Hello World!");

    /* return success status code */
    *(Int *)(&data[0]) = 0;

    return(0);
}
/*
 *  @(#) ti.sdo.rcm.examples.hello; 1,0,0,1; 8-15-2011 11:14:57; /db/atree/library/trees/fc/fc-o26/src/ xlibrary

 */

