#
#  Copyright (c) 2010, Texas Instruments Incorporated
#  All rights reserved.
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions
#  are met:
#
#  *  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#  *  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
#  *  Neither the name of Texas Instruments Incorporated nor the names of
#     its contributors may be used to endorse or promote products derived
#     from this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
#  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
#  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

#
#  ======== xdcpaths.mak ========
#  definition of XDC paths and commands
#
#  This makefile constructs the "search path" for the XDCtools where it finds
#  numerous components and packages needed to build Codec Engine examples and
#  programs.  It also assigns various toolchain locations.  See
#  build_instuctions.html for general details about this file.
#
#  USER NOTE:
#  1) you must specify various <component>_INSTALL_DIRs directores below to
#     reflect your installation, where <component> is CE for Codec Engine,
#     BIOS for DSP/BIOS, etc.
#  2) you must specify compiler path and name in CGTOOLS_* variables below
#  3) you can remove some of the devices from the "DEVICES" list and/or remove
#     some of the types of binaries from the "PROGRAMS" list and/or remove
#     some of the OS runtime environments from the "GPPOS" list to reduce
#     the build time (and possibly avoid checking for presence of a component
#     you don't need)

# (Optional) remove from this list the GPP OS's you're not interested in
# building.  In most cases, you'll likely only leave one, as WinCE users don't
# need Linux, and Linux users don't need WinCE (and probably only want _either_
# GCC or uClibc, but not both)
#
# Note, this is a space-delimited list.
GPPOS := LINUX_GCC LINUX_UCLIBC

# (Optional) Remove from the list the types of programs you're not
# interested in building:
#
# APP_CLIENT -- ARM client for codecs running on the DSP, on dual-CPU systems
# DSP_SERVER -- DSP server with the codecs, running on the DSP, on dual-CPUs
# APP_LOCAL  -- Client+codecs in a single program, whether ARM only or DSP only
#
# Note, this is a space-delimited list.

PROGRAMS := APP_LOCAL


#
# Note, this is a space-delimited list.
#
DEVICES := OMAP3530 OMAPL137 OMAP4430 C6472 C6474 TI816X TI814X C6678 C6670 
DEVICES := TI816X

# ELF TARGETS will be built for if this is set to 1, and not if set to 0 
ELF      := 1

# (Mandatory) Specify where various components are installed.
# What you need depends on what device(s) you're building for, what type(s) of
# programs you are building for, and whether your Codec Engine distribution
# includes a "fctools" directory. The legend:
# XDC     - XDC tools (ARM and DSP)
# BIOS    - SYS/BIOS (DSP only)
# SYSLINK - Arm<->DSP communication software (ARM + DSP)
# XDAIS   - XDAIS header files (ARM and DSP)
# FC      - Framework Components, various resource managers (ARM and DSP)
# CMEM    - Contiguous memory manager (ARM only)
# EDMA3_LLD - EDMA3 Low Level Driver and resource manager (ARM and DSP)
#
# you can omit directory specifications for the components you think you don't
# need (will be warned if you do, based on your DEVICES + PROGRAMS selection
# above).

#XDC_INSTALL_DIR       := _your_XDCTOOLS_installation_directory/xdctools_3_22_01_21
XDC_INSTALL_DIR :=
#BIOS_INSTALL_DIR      := _your_SABIOS_installation_directory/bios_6_32_02_39
BIOS_INSTALL_DIR :=
#FC_INSTALL_DIR        := _your_FC_installation_directory/framework_components_3_21_01_26
FC_INSTALL_DIR :=

# no need to specify the installation directories below if your CE installation
# has fctools/ directory on top
#
# Note, CMEM_INSTALL_DIR is a misnomer - it should be LINUXUTILS_INSTALL_DIR
# but we've got an existing user base.  Need to fix this later.
USE_FCTOOLS_IF_EXISTS := 1

#SYSLINK_INSTALL_DIR   := _your_SysLink_installation_directory/syslink-prebuilt
SYSLINK_INSTALL_DIR   := $(FC_INSTALL_DIR)/fctools/
#XDAIS_INSTALL_DIR     := _your_xDAIS_installation_directory/xdais_7_21_00_02
XDAIS_INSTALL_DIR     := $(FC_INSTALL_DIR)/fctools/
#CMEM_INSTALL_DIR      := _your_CMEM_installation_directory/linuxutils_3_21_00_04
CMEM_INSTALL_DIR      := $(FC_INSTALL_DIR)/fctools/
#EDMA3_LLD_INSTALL_DIR := _your_EDMA3_LLD_installation_directory/edma3_lld_02_11_02_04
EDMA3_LLD_INSTALL_DIR := $(FC_INSTALL_DIR)/fctools/
#OSAL_INSTALL_DIR := _your_OSAL_installation_directory/osal_1_21_01_08
OSAL_INSTALL_DIR := $(FC_INSTALL_DIR)/fctools/
IPC_INSTALL_DIR := _your_IPC_installation_directory


# (Mandatory) specify correct compiler paths and names for the architectures
# you'll be building for:
# compiler path and name for Montavista Arm 9 toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 4.2.0
CGTOOLS_V5T := /db/toolsrc/library/tools/vendors/cs/arm/arm-2007q3
CC_V5T := bin/arm-none-linux-gnueabi-gcc
CGTARGET := gnu.targets.arm.GCArmv5T

# compiler path and name for uClibc toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 4.2.1
CGTOOLS_UCARM9 := /db/toolsrc/library/tools/vendors/opensource/buildroot/10122007/build_arm/staging_dir/usr
#CC_UCARM9 := bin/arm-linux-gcc

# compiler path and name for TI C64x toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 7.0.0
CGTOOLS_C64P := /db/toolsrc/library/tools/vendors/ti/c6x/7.0.0/Linux
# Use compiler version 7.2.0
CGTOOLS_C64Pelf := /db/toolsrc/library/tools/vendors/ti/c6x/7.2.0/Linux


# compiler path and name for TI C64x toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 7.0.0
#CGTOOLS_C66 := /db/toolsrc/library/tools/vendors/ti/c6x/7.0.0/Linux
# Use compiler version 7.2.0
CGTOOLS_C66elf := /db/toolsrc/library/tools/vendors/ti/c6x/7.2.0/Linux

# compiler path and name for TI ARM M3 toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 4.9.0
CGTOOLS_M3elf := /db/toolsrc/library/tools/vendors/ti/arm/4.9.0/Linux

# compiler path and name for TI C674 toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 7.0.0
CGTOOLS_C674 := /db/toolsrc/library/tools/vendors/ti/c6x/7.0.0/Linux
# Use compiler version 7.2.0
CGTOOLS_C674elf := /db/toolsrc/library/tools/vendors/ti/c6x/7.2.0/Linux

# compiler path and name for TI C64T toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 7.2.0
CGTOOLS_C64Telf := /db/toolsrc/library/tools/vendors/ti/c6x/7.2.0/Linux

# compiler path and name for Linux 86 toolchain. NOTE: make sure the
# directory you specify has a "bin" subdirectory
# Use compiler version 4.1.0
CGTOOLS_LINUX86 := /db/toolsrc/library/tools/vendors/opensource/gcc/4.1.0/Linux/gcc-4.1.0-glibc-2.3.6/i686-unknown-linux-gnu

# The above information will be used to generate the XDC_PATH. 
# Any other components your example requires can be added to thsi variable 
# MY_XDC_PATH := <your component>/packages;
MY_XDC_PATH :=

FILECHK := 0

# check above settings for correctness
include $(EXAMPLES_ROOTDIR)/buildutils/xdcpathcheck.mak
